@@ -15,13 +15,13 @@ from .nn import (
     RecursiveSequential,
     LongContextRecursiveSequential,
     RoPE,
+    LoRA,
     Attention,
     MultiHeadAttention,
     RoFormerEncoder,
     AutoRegression,
     LongContextAutoRegression
 )
-from .trainer import TextBinaryClassifierTrainer
 
 __AUTHOR__ = '吴子豪 / Vortez Wohl'
 __EMAIL__ = 'vortez.wohl@gmail.com'
